==> haskell-pem-0.2.4-265-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-E055WtONXpx4tRRUIxGqtb
key:                  pem-0.2.4-E055WtONXpx4tRRUIxGqtb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  36f949eaa7df99d47afecc11628c356a
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-E055WtONXpx4tRRUIxGqtb
depends:
    base-4.15.1.0 basement-0.0.15-IvZTyCKoUdE3jMkDdiQhQ0
    bytestring-0.10.12.1 memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pem-0.2.4-267-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-4peApW3gfWj4GFBAgRMCEc
key:                  pem-0.2.4-4peApW3gfWj4GFBAgRMCEc
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  c594c06cc60a83de06cb6f0a7064c53d
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-4peApW3gfWj4GFBAgRMCEc
depends:
    base-4.15.1.0 basement-0.0.16-Klm23hGhb6c6Td2Q8VURcD
    bytestring-0.10.12.1 memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
